<?php


namespace Lle\ClientHermesBundle\Service;

use Lle\ClientHermesBundle\Exception\MailerException;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

/**
 * This class handles 'template' API calls to Hermès.
 */
class TemplateManager
{
    /**
     * @var string
     */
    protected $urlHermes;

    /**
     * @var HttpClientInterface
     */
    protected $client;

    public function __construct(ParameterBagInterface $parameterBag, HttpClientInterface $client)
    {
        $this->urlHermes = $parameterBag->get("lle.client_hermes.api_url");
        $this->client = $client;
    }

    /**
     * Get all available templates
     * @return array
     */
    public function getAvailableTemplates()
    {
        $url = $this->urlHermes . "/api/mail_templates.json";
        $response = $this->client->request(
            "GET",
            $url
        );

        if ($response->getStatusCode() < 200 || $response->getStatusCode() >= 400) {
            throw new MailerException("API call to $url failed: HTTP " . $response->getStatusCode());
        }

        return json_decode($response->getContent(), true);
    }
}