<?php


namespace Lle\ClientHermesBundle\Test;

use Lle\ClientHermesBundle\Model\Contact;
use Lle\ClientHermesBundle\Service\Mailer;
use PHPUnit\Framework\TestCase;
use Lle\ClientHermesBundle\Model\Mail;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\HttpClient\MockHttpClient;

class MailerTest extends TestCase
{
    /**
     * @var Mailer
     */
    private $mailer;

    public function setUp(): void
    {
        // create mailer
        $parameterBag = $this->createMock(ParameterBagInterface::class);
        $parameterBag->expects($this->once())
            ->method("get")
            ->with("lle.client_hermes.api_url")
            ->willReturn("url.bidon.fr");

        $this->mailer = new Mailer($parameterBag, new MockHttpClient());
    }

    public function testSerialize()
    {
        // This mail contains the minimum required fields for creation on API
        // Please update if the API changes the requirements
        $mail = new Mail();
        $mail
            ->setTemplate("CODE")
            ->setTo([
                new Contact("Toto", "toto@2le.net")
            ]);

        $res = $this->mailer->serializeMail($mail);
        $this->assertArrayHasKey("template_code", $res);
        $this->assertArrayHasKey("destinataire", $res);
        $this->assertGreaterThan(0, $res["destinataire"], "Who you gonna send this mail to ?");
        foreach ($res["destinataire"] as $dest) {
            $this->assertArrayHasKey("toEmail", $dest);
            $this->assertArrayHasKey("toName", $dest);
        }
    }

    // TODO: test other mailer functions
    // when HttpClient is updated (https://github.com/symfony/symfony/commit/d8082fa2f8d9c779e45fe7da0a4299b493235fd2)
}